<?php

namespace Litecms\Teams\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Teams\Http\Requests\TeamsRequest;
use Litecms\Teams\Interfaces\TeamsRepositoryInterface;
use Litecms\Teams\Models\Teams;

/**
 * Resource controller class for teams.
 */
class TeamsResourceController extends BaseController
{

    /**
     * Initialize teams resource controller.
     *
     * @param type TeamsRepositoryInterface $teams
     *
     * @return null
     */
    public function __construct(TeamsRepositoryInterface $teams)
    {
        parent::__construct();
        $this->repository = $teams;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Teams\Repositories\Criteria\TeamsResourceCriteria::class);
    }

    /**
     * Display a list of teams.
     *
     * @return Response
     */
    public function index(TeamsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Teams\Repositories\Presenter\TeamsPresenter::class)
                ->$function();
        }

        $teams = $this->repository->paginate();

        return $this->response->title(trans('teams::teams.names'))
            ->view('teams::teams.index', true)
            ->data(compact('teams'))
            ->output();
    }

    /**
     * Display teams.
     *
     * @param Request $request
     * @param Model   $teams
     *
     * @return Response
     */
    public function show(TeamsRequest $request, Teams $teams)
    {

        if ($teams->exists) {
            $view = 'teams::teams.show';
        } else {
            $view = 'teams::teams.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('teams::teams.name'))
            ->data(compact('teams'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new teams.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TeamsRequest $request)
    {

        $teams = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('teams::teams.name')) 
            ->view('teams::teams.create', true) 
            ->data(compact('teams'))
            ->output();
    }

    /**
     * Create new teams.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TeamsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $teams                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('teams::teams.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('teams/teams/' . $teams->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/teams/teams'))
                ->redirect();
        }

    }

    /**
     * Show teams for editing.
     *
     * @param Request $request
     * @param Model   $teams
     *
     * @return Response
     */
    public function edit(TeamsRequest $request, Teams $teams)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('teams::teams.name'))
            ->view('teams::teams.edit', true)
            ->data(compact('teams'))
            ->output();
    }

    /**
     * Update the teams.
     *
     * @param Request $request
     * @param Model   $teams
     *
     * @return Response
     */
    public function update(TeamsRequest $request, Teams $teams)
    {
        try {
            $attributes = $request->all();

            $teams->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('teams::teams.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('teams/teams/' . $teams->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('teams/teams/' . $teams->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the teams.
     *
     * @param Model   $teams
     *
     * @return Response
     */
    public function destroy(TeamsRequest $request, Teams $teams)
    {
        try {

            $teams->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('teams::teams.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('teams/teams/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('teams/teams/' . $teams->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple teams.
     *
     * @param Model   $teams
     *
     * @return Response
     */
    public function delete(TeamsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('teams::teams.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('teams/teams'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/teams/teams'))
                ->redirect();
        }

    }

    /**
     * Restore deleted teams.
     *
     * @param Model   $teams
     *
     * @return Response
     */
    public function restore(TeamsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('teams::teams.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/teams/teams'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/teams/teams/'))
                ->redirect();
        }

    }

}
